@@ -7,7 +7,7 @@ from typing import Optional
 import click
 
 from .api_client import StudioManagerClient
-from .auth import get_aws_username
+from .auth import get_aws_username, check_aws_auth, detect_aws_environment
 from .progress import format_idle_state, format_time_ago, wait_with_progress
 
 
@@ -118,17 +118,31 @@ def engine_cli():
 @click.option(
     "--skip-ssh-config", is_flag=True, help="Don't automatically update SSH config"
 )
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
 def launch_engine(
     name: str,
     engine_type: str,
     boot_disk_size: Optional[int],
     no_wait: bool,
     skip_ssh_config: bool,
-    env: str,
+    env: Optional[str],
 ):
     """Launch a new engine and wait for it to be ready."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+        click.echo(f"🔍 Detected environment: {env}")
+        
+        # Require confirmation for non-dev environments
+        if env != "dev":
+            if not click.confirm(f"⚠️  You are about to launch in {env.upper()}. Continue?"):
+                click.echo("Cancelled")
+                raise click.Abort()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -192,10 +206,24 @@ def launch_engine(
 @click.option(
     "--skip-ssh-config", is_flag=True, help="Don't automatically update SSH config"
 )
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def start_engine(name_or_id: str, no_wait: bool, skip_ssh_config: bool, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def start_engine(name_or_id: str, no_wait: bool, skip_ssh_config: bool, env: Optional[str]):
     """Start a stopped engine."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+        click.echo(f"🔍 Detected environment: {env}")
+        
+        # Require confirmation for non-dev environments
+        if env != "dev":
+            if not click.confirm(f"⚠️  You are about to operate in {env.upper()}. Continue?"):
+                click.echo("Cancelled")
+                raise click.Abort()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -207,8 +235,6 @@ def start_engine(name_or_id: str, no_wait: bool, skip_ssh_config: bool, env: str
         engine_id = engine["instance_id"]
         engine_name = engine.get("name", engine_id)
 
-        click.echo(f"Starting engine '{engine_name}'...")
-
         result = client.start_engine(engine_id)
 
         if "error" in result:
@@ -294,10 +320,24 @@ def start_engine(name_or_id: str, no_wait: bool, skip_ssh_config: bool, env: str
 
 @engine_cli.command("stop")
 @click.argument("name_or_id")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def stop_engine(name_or_id: str, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def stop_engine(name_or_id: str, env: Optional[str]):
     """Stop a running engine."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+        click.echo(f"🔍 Detected environment: {env}")
+        
+        # Require confirmation for non-dev environments
+        if env != "dev":
+            if not click.confirm(f"⚠️  You are about to operate in {env.upper()}. Continue?"):
+                click.echo("Cancelled")
+                raise click.Abort()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -327,10 +367,24 @@ def stop_engine(name_or_id: str, env: str):
 @engine_cli.command("terminate")
 @click.argument("name_or_id")
 @click.option("--yes", "-y", is_flag=True, help="Skip confirmation")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def terminate_engine(name_or_id: str, yes: bool, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def terminate_engine(name_or_id: str, yes: bool, env: Optional[str]):
     """Terminate an engine."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+        click.echo(f"🔍 Detected environment: {env}")
+        
+        # Require confirmation for non-dev environments
+        if env != "dev":
+            if not click.confirm(f"⚠️  You are about to operate in {env.upper()}. Continue?"):
+                click.echo("Cancelled")
+                raise click.Abort()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -369,11 +423,17 @@ def terminate_engine(name_or_id: str, yes: bool, env: str):
 
 @engine_cli.command("status")
 @click.argument("name_or_id")
-@click.option("--detailed", is_flag=True, help="Show detailed sensor information")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def engine_status(name_or_id: str, detailed: bool, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def engine_status(name_or_id: str, env: Optional[str]):
     """Show engine status including idle detector state."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -392,12 +452,10 @@ def engine_status(name_or_id: str, detailed: bool, env: str):
             click.echo(f"✗ Error: {status_data['error']}", err=True)
             raise click.Abort()
 
-        # Display basic info
+        # Display basic info - reordered per user request
         engine_name = status_data.get("name", engine_id)
-        click.echo(f"Engine: \033[34m{engine_name}\033[0m")  # Blue engine name
-        click.echo(f"Instance ID: {engine_id}")
-        click.echo(f"Type: {status_data.get('instance_type', 'unknown')}")
-
+        click.echo(f"Name: \033[34m{engine_name}\033[0m")  # Blue engine name (renamed from "Engine")
+        
         # Show state in red if stopped, normal otherwise
         engine_state = status_data.get("state", "unknown")
         if engine_state.lower() in ["stopped", "stopping", "terminated", "terminating"]:
@@ -405,11 +463,14 @@ def engine_status(name_or_id: str, detailed: bool, env: str):
         else:
             click.echo(f"State: {engine_state}")
 
-        if status_data.get("public_ip"):
-            click.echo(f"Public IP: {status_data['public_ip']}")
-
         if status_data.get("launch_time"):
             click.echo(f"Launched: {format_time_ago(status_data['launch_time'])}")
+        
+        click.echo(f"Type: {status_data.get('instance_type', 'unknown')}")
+        click.echo(f"Instance ID: {engine_id}")
+
+        if status_data.get("public_ip"):
+            click.echo(f"Public IP: {status_data['public_ip']}")
 
         # Check if engine is stopped - don't show idle state or activity sensors
         if engine_state.lower() in ["stopped", "stopping", "terminated", "terminating"]:
@@ -429,11 +490,11 @@ def engine_status(name_or_id: str, detailed: bool, env: str):
                     remaining = readiness["estimated_time_remaining_seconds"]
                     click.echo(f"Estimated Time Remaining: {remaining}s")
 
-        # Show idle state (only for running engines)
+        # Show idle state (only for running engines) - always detailed per user request
         if status_data.get("idle_state"):
             attached_studios = status_data.get("attached_studios", [])
             click.echo(
-                f"\n{format_idle_state(status_data['idle_state'], detailed=detailed, attached_studios=attached_studios)}"
+                f"\n{format_idle_state(status_data['idle_state'], detailed=True, attached_studios=attached_studios)}"
             )
 
     except Exception as e:
@@ -442,10 +503,17 @@ def engine_status(name_or_id: str, detailed: bool, env: str):
 
 
 @engine_cli.command("list")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def list_engines(env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def list_engines(env: Optional[str]):
     """List all engines."""
 
+    # Check AWS auth first to provide clear error messages
+    check_aws_auth()
+    
+    # Auto-detect environment if not specified
+    if env is None:
+        env = detect_aws_environment()
+
     client = StudioManagerClient(environment=env)
 
     try:
@@ -456,18 +524,19 @@ def list_engines(env: str):
             click.echo("No engines found")
             return
 
-        # Table header
-        click.echo(f"{'Name':<30} {'Instance ID':<20} {'Type':<15} {'State':<10}")
-        click.echo("-" * 80)
+        # Table header - reordered per user request: Name, State, User, Type, Instance ID
+        click.echo(f"{'Name':<30} {'State':<10} {'User':<15} {'Type':<15} {'Instance ID':<20}")
+        click.echo("-" * 95)
 
         # Table rows
         for engine in engines:
             name = engine.get("name", "unknown")[:29]
-            instance_id = engine.get("instance_id", "unknown")
-            engine_type = engine.get("engine_type", "unknown")
             state = engine.get("state", "unknown")
+            user = engine.get("user", "unknown")[:14]
+            engine_type = engine.get("engine_type", "unknown")
+            instance_id = engine.get("instance_id", "unknown")
 
-            click.echo(f"{name:<30} {instance_id:<20} {engine_type:<15} {state:<10}")
+            click.echo(f"{name:<30} {state:<10} {user:<15} {engine_type:<15} {instance_id:<20}")
 
         click.echo(f"\nTotal: {len(engines)} engine(s)")
 
@@ -489,11 +558,16 @@ def list_engines(env: str):
     is_flag=True,
     help="Generate entries using ec2-user instead of owner",
 )
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def config_ssh(clean: bool, all: bool, admin: bool, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def config_ssh(clean: bool, all: bool, admin: bool, env: Optional[str]):
     """Update SSH config with available engines."""
+    
+    # Auto-detect environment if not specified (and not just cleaning)
+    if env is None and not clean:
+        check_aws_auth()
+        env = detect_aws_environment()
 
-    client = StudioManagerClient(environment=env)
+    client = StudioManagerClient(environment=env if env else "dev")
     ssh_config_path = os.path.expanduser("~/.ssh/config")
 
     try:
@@ -560,11 +634,19 @@ def config_ssh(clean: bool, all: bool, admin: bool, env: str):
 
             username = "ec2-user" if admin else user
 
+            # Map environment to AWS profile
+            profile_map = {
+                "dev": "dev-devaccess",
+                "sand": "sand-devaccess",
+                "prod": "prod-devaccess",
+            }
+            aws_profile = profile_map.get(env, f"{env}-devaccess")
+
             config_entries.append(f"\nHost {name}\n")
             config_entries.append(f"    HostName {instance_id}\n")
             config_entries.append(f"    User {username}\n")
             config_entries.append(
-                f"    ProxyCommand aws ssm start-session --target %h --document-name AWS-StartSSHSession --parameters 'portNumber=%p'\n"
+                f"    ProxyCommand aws ssm start-session --target %h --document-name AWS-StartSSHSession --parameters 'portNumber=%p' --profile {aws_profile}\n"
             )
 
         config_entries.append(managed_end)
@@ -591,9 +673,15 @@ def config_ssh(clean: bool, all: bool, admin: bool, env: str):
 @click.argument("name_or_id")
 @click.argument("duration", required=False)
 @click.option("--cancel", is_flag=True, help="Cancel existing coffee lock")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def coffee(name_or_id: str, duration: Optional[str], cancel: bool, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def coffee(name_or_id: str, duration: Optional[str], cancel: bool, env: Optional[str]):
     """Keep engine awake for specified duration (e.g., '4h', '2h30m')."""
+    
+    # Check AWS auth and auto-detect environment if not specified
+    check_aws_auth()
+    
+    if env is None:
+        env = detect_aws_environment()
 
     client = StudioManagerClient(environment=env)
 
@@ -636,11 +724,17 @@ def coffee(name_or_id: str, duration: Optional[str], cancel: bool, env: str):
     type=click.Choice(["none", "default", "all"]),
     help="Set Slack notifications",
 )
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
 def idle_timeout_cmd(
-    name_or_id: str, set_timeout: Optional[str], slack: Optional[str], env: str
+    name_or_id: str, set_timeout: Optional[str], slack: Optional[str], env: Optional[str]
 ):
     """Show or configure idle detector settings."""
+    
+    # Check AWS auth and auto-detect environment if not specified
+    check_aws_auth()
+    
+    if env is None:
+        env = detect_aws_environment()
 
     client = StudioManagerClient(environment=env)
 
@@ -700,9 +794,15 @@ def idle_timeout_cmd(
     help="Resize while running (requires manual filesystem expansion)",
 )
 @click.option("--force", "-f", is_flag=True, help="Force resize")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def resize_engine(name_or_id: str, size: int, online: bool, force: bool, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def resize_engine(name_or_id: str, size: int, online: bool, force: bool, env: Optional[str]):
     """Resize an engine's boot disk."""
+    
+    # Check AWS auth and auto-detect environment if not specified
+    check_aws_auth()
+    
+    if env is None:
+        env = detect_aws_environment()
 
     client = StudioManagerClient(environment=env)
 
@@ -737,9 +837,15 @@ def resize_engine(name_or_id: str, size: int, online: bool, force: bool, env: st
 
 @engine_cli.command("gami")
 @click.argument("name_or_id")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def create_ami(name_or_id: str, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def create_ami(name_or_id: str, env: Optional[str]):
     """Create a Golden AMI from an engine."""
+    
+    # Check AWS auth and auto-detect environment if not specified
+    check_aws_auth()
+    
+    if env is None:
+        env = detect_aws_environment()
 
     client = StudioManagerClient(environment=env)
 
@@ -771,9 +877,15 @@ def create_ami(name_or_id: str, env: str):
 
 @engine_cli.command("debug")
 @click.argument("name_or_id")
-@click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def debug_engine(name_or_id: str, env: str):
+@click.option("--env", default=None, help="Environment (dev, sand, prod) - auto-detected if not specified")
+def debug_engine(name_or_id: str, env: Optional[str]):
     """Debug engine bootstrap status and files."""
+    
+    # Check AWS auth and auto-detect environment if not specified
+    check_aws_auth()
+    
+    if env is None:
+        env = detect_aws_environment()
 
     client = StudioManagerClient(environment=env)
 
